summaryrefslogtreecommitdiffhomepage
path: root/gui/scripts
diff options
context:
space:
mode:
Diffstat (limited to 'gui/scripts')
-rw-r--r--gui/scripts/README.md12
-rwxr-xr-xgui/scripts/build-logo-icons.sh14
2 files changed, 20 insertions, 6 deletions
diff --git a/gui/scripts/README.md b/gui/scripts/README.md
index cd9b723045..7fd98fb217 100644
--- a/gui/scripts/README.md
+++ b/gui/scripts/README.md
@@ -1,7 +1,9 @@
This is a folder with the supporting scripts written in Python 3, node, bash.
-## Dependency installation notes
+## Maps and location translations
+
+### Dependency installation notes
1. Install GDAL/OGR dependencies, which are required by Fiona python package.
@@ -20,7 +22,7 @@ This is a folder with the supporting scripts written in Python 3, node, bash.
https://www.gnu.org/software/gettext/
-## Geo data installation notes
+### Geo data installation notes
Go to http://www.naturalearthdata.com/downloads/50m-cultural-vectors/ and
download ZIP files with the following shapes:
@@ -52,7 +54,7 @@ unzip ne_50m_admin_1_states_provinces_lines.zip -d ne_50m_admin_1_states_provinc
unzip ne_10m_populated_places.zip -d ne_10m_populated_places/
```
-## Geo data extraction notes
+### Geo data extraction notes
Run the following script to produce a TopoJSON data used by the app:
@@ -68,7 +70,7 @@ npm exec ts-node prepare-rtree.ts
At this point all of the data should be saved in `gui/scripts/out` folder.
-## App integration notes
+### App integration notes
Once you've extracted all the geo data, run the integration script that will
copy all files ignoring intermediate ones into the `gui/assets/geo` folder:
@@ -77,7 +79,7 @@ copy all files ignoring intermediate ones into the `gui/assets/geo` folder:
python3 integrate-into-app.py
```
-## Locking Python dependencies
+### Locking Python dependencies
1. Freeze dependencies:
diff --git a/gui/scripts/build-logo-icons.sh b/gui/scripts/build-logo-icons.sh
index 78d8652096..7002d565ee 100755
--- a/gui/scripts/build-logo-icons.sh
+++ b/gui/scripts/build-logo-icons.sh
@@ -1,12 +1,22 @@
#!/usr/bin/env bash
# Icon guidlines for MacOS:
# https://developer.apple.com/design/human-interface-guidelines/macos/icons-and-images/app-icon/
#
+# Icon templates for macOS:
+# https://developer.apple.com/design/resources/
+#
# Icon guidlines for Windows:
# https://docs.microsoft.com/en-us/windows/uwp/design/style/app-icons-and-logos#target-size-app-icon-assets
# https://docs.microsoft.com/en-us/windows/win32/uxguide/vis-icons
+echo "Press enter to continue if you've followed the instructions in graphics/README.md"
+read -r
+
set -eu
if ! command -v convert > /dev/null; then
@@ -24,6 +34,8 @@ if ! command -v iconutil > /dev/null; then
exit 1
fi
+
+
SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
cd "$SCRIPT_DIR"
@@ -1,12 +1,22 @@
#!/usr/bin/env bash
-# Icon guidlines for MacOS:
+# This script creates the macOS .icns from the icons in /graphics/macOS/ which need to be updated
+# first if the source SVGs have been updated. More info about how to update them can be found in
+# the readme.
+#
+# Icon guidlines for macOS:
# https://developer.apple.com/design/human-interface-guidelines/macos/icons-and-images/app-icon/
#